@@ -6,8 +6,12 @@ from dataclasses import dataclass
 from typing import Optional
 
 import numpy as np
-from sklearn.base import BaseEstimator, clone, is_classifier
+from sklearn.base import BaseEstimator
+from sklearn.base import clone
+from sklearn.base import is_classifier
 from sklearn.model_selection import KFold
+from sklearn.utils import check_random_state
+from sklearn.utils import check_scalar
 
 from ..utils import check_bandit_feedback_inputs
 
@@ -33,8 +37,8 @@ class RegressionModel(BaseEstimator):
         When Open Bandit Dataset is used, 3 should be set.
 
     action_context: array-like, shape (n_actions, dim_action_context), default=None
-        Context vector characterizing each action, vector representation of each action.
-        If not given, then one-hot encoding of the action variable is automatically used.
+        Context vector characterizing action (i.e., vector representation of each action).
+        If not given, one-hot encoding of the action variable is used as default.
 
     fitting_method: str, default='normal'
         Method to fit the regression model.
@@ -62,6 +66,8 @@ class RegressionModel(BaseEstimator):
 
     def __post_init__(self) -> None:
         """Initialize Class."""
+        check_scalar(self.n_actions, "n_actions", int, min_val=2)
+        check_scalar(self.len_list, "len_list", int, min_val=1)
         if not (
             isinstance(self.fitting_method, str)
             and self.fitting_method in ["normal", "iw", "mrdr"]
@@ -69,14 +75,6 @@ class RegressionModel(BaseEstimator):
             raise ValueError(
                 f"fitting_method must be one of 'normal', 'iw', or 'mrdr', but {self.fitting_method} is given"
             )
-        if not (isinstance(self.n_actions, int) and self.n_actions > 1):
-            raise ValueError(
-                f"n_actions must be an integer larger than 1, but {self.n_actions} is given"
-            )
-        if not (isinstance(self.len_list, int) and self.len_list > 0):
-            raise ValueError(
-                f"len_list must be a positive integer, but {self.len_list} is given"
-            )
         if not isinstance(self.base_model, BaseEstimator):
             raise ValueError(
                 "base_model must be BaseEstimator or a child class of BaseEstimator"
@@ -102,26 +100,25 @@ class RegressionModel(BaseEstimator):
         Parameters
         ----------
         context: array-like, shape (n_rounds, dim_context)
-            Context vectors in each round, i.e., :math:`x_t`.
+            Context vectors observed in each round of the logged bandit feedback, i.e., :math:`x_t`.
 
         action: array-like, shape (n_rounds,)
-            Action sampled by a behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+            Action sampled by behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
 
         reward: array-like, shape (n_rounds,)
-            Observed rewards (or outcome) in each round, i.e., :math:`r_t`.
+            Reward observed in each round of the logged bandit feedback, i.e., :math:`r_t`.
 
-        pscore: array-like, shape (n_rounds,), default=None
-            Action choice probabilities (propensity score) of a behavior policy
-            in the training logged bandit feedback.
-            When None is given, the behavior policy is assumed to be a uniform one.
+        pscore: array-like, shape (n_rounds,)
+            Action choice probabilities of behavior policy (propensity scores), i.e., :math:`\\pi_b(a_t|x_t)`.
+            When None is given, behavior policy is assumed to be uniform.
 
         position: array-like, shape (n_rounds,), default=None
-            Positions of each round in the given logged bandit feedback.
+            Position of recommendation interface where action was presented in each round of the given logged bandit data.
             If None is set, a regression model assumes that there is only one position.
             When `len_list` > 1, this position argument has to be set.
 
         action_dist: array-like, shape (n_rounds, n_actions, len_list), default=None
-            Action choice probabilities by the evaluation policy (can be deterministic), i.e., :math:`\\pi_e(a_t|x_t)`.
+            Action choice probabilities of evaluation policy (can be deterministic), i.e., :math:`\\pi_e(a_t|x_t)`.
             When either of 'iw' or 'mrdr' is used as the 'fitting_method' argument, then `action_dist` must be given.
 
         """
@@ -193,12 +190,12 @@ class RegressionModel(BaseEstimator):
         Parameters
         -----------
         context: array-like, shape (n_rounds_of_new_data, dim_context)
-            Context vectors for new data.
+            Context vectors of new data.
 
         Returns
         -----------
         estimated_rewards_by_reg_model: array-like, shape (n_rounds_of_new_data, n_actions, len_list)
-            Estimated expected rewards for new data by the regression model.
+            Expected rewards of new data estimated by the regression model.
 
         """
         n_rounds_of_new_data = context.shape[0]
@@ -246,10 +243,10 @@ class RegressionModel(BaseEstimator):
         Parameters
         ----------
         context: array-like, shape (n_rounds, dim_context)
-            Context vectors in each round, i.e., :math:`x_t`.
+            Context vectors observed in each round of the logged bandit feedback, i.e., :math:`x_t`.
 
         action: array-like, shape (n_rounds,)
-            Action sampled by a behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+            Action sampled by behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
 
         reward: array-like, shape (n_rounds,)
             Observed rewards (or outcome) in each round, i.e., :math:`r_t`.
@@ -260,12 +257,12 @@ class RegressionModel(BaseEstimator):
             When None is given, the the behavior policy is assumed to be a uniform one.
 
         position: array-like, shape (n_rounds,), default=None
-            Positions of each round in the given logged bandit feedback.
+            Position of recommendation interface where action was presented in each round of the given logged bandit data.
             If None is set, a regression model assumes that there is only one position.
             When `len_list` > 1, this position argument has to be set.
 
         action_dist: array-like, shape (n_rounds, n_actions, len_list), default=None
-            Action choice probabilities by the evaluation policy (can be deterministic), i.e., :math:`\\pi_e(a_t|x_t)`.
+            Action choice probabilities of evaluation policy (can be deterministic), i.e., :math:`\\pi_e(a_t|x_t)`.
             When either of 'iw' or 'mrdr' is used as the 'fitting_method' argument, then `action_dist` must be given.
 
         n_folds: int, default=1
@@ -280,7 +277,7 @@ class RegressionModel(BaseEstimator):
         Returns
         -----------
         estimated_rewards_by_reg_model: array-like, shape (n_rounds, n_actions, len_list)
-            Estimated expected rewards for new data by the regression model.
+            Expected rewards of new data estimated by the regression model.
 
         """
         check_bandit_feedback_inputs(
@@ -293,15 +290,8 @@ class RegressionModel(BaseEstimator):
         )
         n_rounds = context.shape[0]
 
-        if not (isinstance(n_folds, int) and n_folds > 0):
-            raise ValueError(
-                f"n_folds must be a positive integer, but {n_folds} is given"
-            )
-
-        if random_state is not None and not isinstance(random_state, int):
-            raise ValueError(
-                f"random_state must be an integer, but {random_state} is given"
-            )
+        check_scalar(n_folds, "n_folds", int, min_val=1)
+        check_random_state(random_state)
 
         if position is None or self.len_list == 1:
             position = np.zeros_like(action)
@@ -361,7 +351,7 @@ class RegressionModel(BaseEstimator):
         action: np.ndarray,
         action_context: np.ndarray,
     ) -> np.ndarray:
-        """Preprocess feature vectors to train a give regression model.
+        """Preprocess feature vectors to train a regression model.
 
         Note
         -----
@@ -371,13 +361,13 @@ class RegressionModel(BaseEstimator):
         Parameters
         -----------
         context: array-like, shape (n_rounds,)
-            Context vectors in the training logged bandit feedback.
+            Context vectors observed in each round of the logged bandit feedback, i.e., :math:`x_t`.
 
         action: array-like, shape (n_rounds,)
-            Action sampled by a behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
+            Action sampled by behavior policy in each round of the logged bandit feedback, i.e., :math:`a_t`.
 
         action_context: array-like, shape shape (n_actions, dim_action_context)
-            Context vector characterizing each action, vector representation of each action.
+            Context vector characterizing action (i.e., vector representation of each action).
 
         """
         return np.c_[context, action_context[action]]
