@@ -1,23 +1,27 @@
 from obp.policy.base import BaseContextFreePolicy
 from obp.policy.base import BaseContextualPolicy
+from obp.policy.base import BaseContinuousOfflinePolicyLearner
 from obp.policy.base import BaseOfflinePolicyLearner
+from obp.policy.contextfree import BernoulliTS
 from obp.policy.contextfree import EpsilonGreedy
 from obp.policy.contextfree import Random
-from obp.policy.contextfree import BernoulliTS
 from obp.policy.linear import LinEpsilonGreedy
-from obp.policy.linear import LinUCB
 from obp.policy.linear import LinTS
+from obp.policy.linear import LinUCB
 from obp.policy.logistic import LogisticEpsilonGreedy
-from obp.policy.logistic import LogisticUCB
 from obp.policy.logistic import LogisticTS
+from obp.policy.logistic import LogisticUCB
 from obp.policy.logistic import MiniBatchLogisticRegression
 from obp.policy.offline import IPWLearner
+from obp.policy.offline import NNPolicyLearner
+from obp.policy.offline_continuous import ContinuousNNPolicyLearner
 
 
 __all__ = [
     "BaseContextFreePolicy",
     "BaseContextualPolicy",
     "BaseOfflinePolicyLearner",
+    "BaseContinuousOfflinePolicyLearner",
     "EpsilonGreedy",
     "Random",
     "BernoulliTS",
@@ -29,4 +33,6 @@ __all__ = [
     "LogisticTS",
     "MiniBatchLogisticRegression",
     "IPWLearner",
+    "NNPolicyLearner",
+    "ContinuousNNPolicyLearner",
 ]
