@@ -2,12 +2,14 @@
 # Licensed under the Apache 2.0 License.
 
 """Base Interfaces for Bandit Algorithms."""
-from abc import ABCMeta, abstractmethod
+from abc import ABCMeta
+from abc import abstractmethod
 from dataclasses import dataclass
 from typing import Optional
 
 import numpy as np
 from sklearn.utils import check_random_state
+from sklearn.utils import check_scalar
 
 from .policy_type import PolicyType
 
@@ -40,26 +42,9 @@ class BaseContextFreePolicy(metaclass=ABCMeta):
 
     def __post_init__(self) -> None:
         """Initialize Class."""
-        if not isinstance(self.n_actions, int) or self.n_actions <= 1:
-            raise ValueError(
-                f"n_actions must be an integer larger than 1, but {self.n_actions} is given"
-            )
-
-        if not isinstance(self.len_list, int) or self.len_list <= 0:
-            raise ValueError(
-                f"len_list must be a positive integer, but {self.len_list} is given"
-            )
-
-        if not isinstance(self.batch_size, int) or self.batch_size <= 0:
-            raise ValueError(
-                f"batch_size must be a positive integer, but {self.batch_size} is given"
-            )
-
-        if self.n_actions < self.len_list:
-            raise ValueError(
-                f"n_actions >= len_list should hold, but n_actions is {self.n_actions} and len_list is {self.len_list}"
-            )
-
+        check_scalar(self.n_actions, "n_actions", int, min_val=2)
+        check_scalar(self.len_list, "len_list", int, min_val=1, max_val=self.n_actions)
+        check_scalar(self.batch_size, "batch_size", int, min_val=1)
         self.n_trial = 0
         self.random_ = check_random_state(self.random_state)
         self.action_counts = np.zeros(self.n_actions, dtype=int)
@@ -111,12 +96,6 @@ class BaseContextualPolicy(metaclass=ABCMeta):
     batch_size: int, default=1
         Number of samples used in a batch parameter update.
 
-    alpha_: float, default=1.
-        Prior parameter for the online logistic regression.
-
-    lambda_: float, default=1.
-        Regularization hyperparameter for the online logistic regression.
-
     random_state: int, default=None
         Controls the random seed in sampling actions.
 
@@ -126,49 +105,16 @@ class BaseContextualPolicy(metaclass=ABCMeta):
     n_actions: int
     len_list: int = 1
     batch_size: int = 1
-    alpha_: float = 1.0
-    lambda_: float = 1.0
     random_state: Optional[int] = None
 
     def __post_init__(self) -> None:
         """Initialize class."""
-        if not isinstance(self.dim, int) or self.dim <= 0:
-            raise ValueError(f"dim must be a positive integer, but {self.dim} is given")
-
-        if not isinstance(self.n_actions, int) or self.n_actions <= 1:
-            raise ValueError(
-                f"n_actions must be an integer larger than 1, but {self.n_actions} is given"
-            )
-
-        if not isinstance(self.len_list, int) or self.len_list <= 0:
-            raise ValueError(
-                f"len_list must be a positive integer, but {self.len_list} is given"
-            )
-
-        if not isinstance(self.batch_size, int) or self.batch_size <= 0:
-            raise ValueError(
-                f"batch_size must be a positive integer, but {self.batch_size} is given"
-            )
-
-        if self.n_actions < self.len_list:
-            raise ValueError(
-                f"n_actions >= len_list should hold, but n_actions is {self.n_actions} and len_list is {self.len_list}"
-            )
-
-        if not isinstance(self.alpha_, float) or self.alpha_ <= 0.0:
-            raise ValueError(
-                f"alpha_ should be a positive float, but {self.alpha_} is given"
-            )
-
-        if not isinstance(self.lambda_, float) or self.lambda_ <= 0.0:
-            raise ValueError(
-                f"lambda_ should be a positive float, but {self.lambda_} is given"
-            )
-
+        check_scalar(self.dim, "dim", int, min_val=1)
+        check_scalar(self.n_actions, "n_actions", int, min_val=2)
+        check_scalar(self.len_list, "len_list", int, min_val=1, max_val=self.n_actions)
+        check_scalar(self.batch_size, "batch_size", int, min_val=1)
         self.n_trial = 0
         self.random_ = check_random_state(self.random_state)
-        self.alpha_list = self.alpha_ * np.ones(self.n_actions)
-        self.lambda_list = self.lambda_ * np.ones(self.n_actions)
         self.action_counts = np.zeros(self.n_actions, dtype=int)
         self.reward_lists = [[] for _ in np.arange(self.n_actions)]
         self.context_lists = [[] for _ in np.arange(self.n_actions)]
@@ -217,20 +163,8 @@ class BaseOfflinePolicyLearner(metaclass=ABCMeta):
 
     def __post_init__(self) -> None:
         """Initialize class."""
-        if not isinstance(self.n_actions, int) or self.n_actions <= 1:
-            raise ValueError(
-                f"n_actions must be an integer larger than 1, but {self.n_actions} is given"
-            )
-
-        if not isinstance(self.len_list, int) or self.len_list <= 0:
-            raise ValueError(
-                f"len_list must be a positive integer, but {self.len_list} is given"
-            )
-
-        if self.n_actions < self.len_list:
-            raise ValueError(
-                f"n_actions >= len_list should hold, but n_actions is {self.n_actions} and len_list is {self.len_list}"
-            )
+        check_scalar(self.n_actions, "n_actions", int, min_val=2)
+        check_scalar(self.len_list, "len_list", int, min_val=1, max_val=self.n_actions)
 
     @property
     def policy_type(self) -> PolicyType:
@@ -260,3 +194,37 @@ class BaseOfflinePolicyLearner(metaclass=ABCMeta):
 
         """
         raise NotImplementedError
+
+
+@dataclass
+class BaseContinuousOfflinePolicyLearner(metaclass=ABCMeta):
+    """Base class for off-policy learners for the continuous action setting."""
+
+    @property
+    def policy_type(self) -> PolicyType:
+        """Type of the bandit policy."""
+        return PolicyType.OFFLINE
+
+    @abstractmethod
+    def fit(
+        self,
+    ) -> None:
+        """Fits an offline bandit policy using the given logged bandit feedback data."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def predict(self, context: np.ndarray) -> np.ndarray:
+        """Predict the best continuous action value for new data.
+
+        Parameters
+        -----------
+        context: array-like, shape (n_rounds_of_new_data, dim_context)
+            Context vectors for new data.
+
+        Returns
+        -----------
+        action: array-like, shape (n_rounds_of_new_data,)
+            Action choices by a policy trained by calling the `fit` method.
+
+        """
+        raise NotImplementedError
