@@ -2,10 +2,14 @@
 # Licensed under the Apache 2.0 License.
 
 """Types."""
-from typing import Union, Dict
+from typing import Dict
+from typing import Union
+
 import numpy as np
 
-from .policy import BaseContextFreePolicy, BaseContextualPolicy
+from .policy import BaseContextFreePolicy
+from .policy import BaseContextualPolicy
+
 
 # dataset
 BanditFeedback = Dict[str, Union[int, np.ndarray]]
